/**************************************************************************//**
*   @file   ad5694r.h
*   @brief  Header file of AD5694R Driver for NIOS processor.
*   @author DBogdan (dragos.bogdan@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 1004
******************************************************************************/
#ifndef _AD5694R_H_
#define _AD5694R_H_
#ifdef AD5694R_GLOBALS
    #define AD5694R_EXT extern volatile
#else
    #define AD5694R_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "adi.h"
#if (USE_AD5694R == 1)


/*****************************************************************************/
/* AD5694R                                                                   */
/*****************************************************************************/

typedef enum _AD5694RCommand
{
    NO_OPERATION                            = 0x00,
    WRITE_TO_INPUT_REGISTER_N               = 0x01,
    UPDATE_DAC_REGISTER_N                   = 0x02,
    WRITE_TO_REGISTER_AND_UPDATE_CHANNEL_N  = 0x03,
    POWER_DOWN_POWER_UP_DAC                 = 0x04,
    HARDWARE_LDAC_N_MASK_REGISTER           = 0x05,
    SOFTWARE_RESET                          = 0x06,
    INTERNAL_REFERENCE_SETUP_REGISTER       = 0x07,
}AD5694RCommand;

typedef enum _AD5694RChannel
{
    CHANNEL_A   = 0x01,
    CHANNEL_B   = 0x02,
    CHANNEL_C   = 0x04,
    CHANNEL_D   = 0x08
}AD5694RChannel;

#define AD5694RCMDPOSITION  20
#define AD5694RCHANPOSITION 16
#define AD5694RDATAPOSITION 4

#define INTERN_REF_ON       (1)

#define PWR_NORM            (0)
#define PWR_1K              (1)
#define PWR_100K            (2)
#define PWR_THREES          (3)

#define PWRPOSITIONA        (0)
#define PWRPOSITIONB        (2)
#define PWRPOSITIONC        (4)
#define PWRPOSITIOND        (6)

#define MAXVALUE            4095

/*****************************************************************************/
/* I2C                                                                       */
/*****************************************************************************/
#define AD5694R_ADDRESS         0x0E

/*****************************************************************************/
/* GPIO                                                                      */
/*****************************************************************************/
#define GPIO_LDAC   (1<<0)  // LDAC Pin.
#define GPIO_RESET  (1<<1)  // RESET Pin.

/*****************************************************************************/
/* Monitored variables declarations                                          */
/*****************************************************************************/
AD5694R_EXT uCProbeDataUnion ucProbe_Data[32];  // Used to store the values for uC-Probe communication.
#endif //(USE_AD5694R == 1)

/*****************************************************************************/
/* Functions Prototypes                                                      */
/*****************************************************************************/
//driver functions
int AD5694R_Init(void);                     // Initializes the communication with the device.
void AD5694R_Set(int value);                // Write data to DAC
unsigned int AD5694R_Get(unsigned char channel);                 // Read data from DAC
void AD5694R_SetDac(int channel, int iDAC); // Set data on DAC channel

//interface specific functions
int AD5694R_UpdateParameters(void);         // Updates the device's monitored and controlled parameters.

#endif /* AD5694_H_ */
